function PwgDataHandler( map )
{
  this._map = map;
  this._map.getInfoWindow();
}

PwgDataHandler.prototype =  {

_map: null,
_markers: new Array(),
_navHtmlIds: ["gotoPrevImage", "gotoNextImage"],
_timerBindPictureNavigation: null,
_prevResult: { nb_images:0 },

_showAllImgSrc: null,

setShowAllImageSource: function( url )
{
  this._showAllImgSrc = url;
},

handle: function( data )
{
  var i;
  var newMarkers = [];
  if (document.title != data.title )
    document.title = data.title;
  var elt = document.getElementById("aPageUrl");
  if (elt && elt.href!=data.page_url.urlNoHtm() )
  {
    elt.href = data.page_url.urlNoHtm();
    elt.innerHTML = data.title;
    elt.title = Localization.fmt1("go to %s", data.title);
  }
  var elt = document.getElementById("aBlowup");
  if (elt && elt.href!=data.blowup_url.urlNoHtm())
     elt.href = data.blowup_url.urlNoHtm();

  var elt = document.getElementById("aKml");
  if (elt && elt.href!=data.kml_url.urlNoHtm())
  {
     elt.href = data.kml_url.urlNoHtm();
     elt.title = Localization.fmt1("opens %s in Google Earth", data.title);
  }
  var changed = true;
  if (this._prevResult.nb_images==data.nb_images && this._markers.length==data.image_clusters.length )
  {
    changed = false;
    if (this._markers.length>0 && !this._markers[0].getPoint().equals( data.image_clusters[0].position ) )
      changed=true;
  }

  if (changed)
  {
    for (i=0; i<data.image_clusters.length; i++)
    {
      var cluster = data.image_clusters[i];
      var theTitle = "";
      if (cluster.nb_items>1)
        theTitle = Localization.fmt1("%d images", cluster.nb_items);
      else
        theTitle = cluster.items[0].name;
      var marker = new GMarker( cluster.position, {title:  theTitle } );
      GEvent.addListener( marker, "click", this._onMarkerClick.bind(this, marker) );
      marker.images = cluster.items;
      marker.blowup_url = cluster.blowup_url;
      newMarkers.push(marker);
    }

    for (i=0; i<this._markers.length; i++)
    {
      this._map.removeOverlay( this._markers[i] );
      GEvent.clearListeners(this._markers[i], "click" );
    }

    this._markers = newMarkers;

    for (i=0; i<this._markers.length; i++)
      this._map.addOverlay( this._markers[i] );

    this._prevResult.nb_images=data.nb_images;
  }

  document.getElementById("dataLoadStatus").innerHTML = Localization.fmt1("%d images", data.nb_items);
},

_onMarkerClick: function( marker )
{
  var content = "";
  if ( !marker.currentImageIndex )
    marker.currentImageIndex = 0;
  content += '<div class="gmiw_header" style="' + (marker.images.length>1 ? '': 'display:none')+ '">';
  content += '<span id="pwgImageCounters">'+this.buildCurrentPictureCounterHtml(marker)+'</span> ';
  content += '<a href="javascript:void(0);" id="'+this._navHtmlIds[0]+'">';
  content +=    '<span>'+ "&laquo; " + Localization.get('Prev') + '</span>';
  content += '</a>';
  content += " ";
  content += '<a href="javascript:void(0);" id="'+this._navHtmlIds[1]+'">';
  content +=    '<span>'+Localization.get('Next') + " &raquo;"+'</span>';
  content += '</a>';
  content += " ";
  var imgShowAll = '';
  if (this._showAllImgSrc)
    imgShowAll = '<img src="'+this._showAllImgSrc+'" alt="" style="border:0" /> ';
  content += '<a id="pwgImageBlowup" href="'+marker.blowup_url+'" onclick="return PwgDataHandler.blowupUrl(this.href);" title='+Localization.getQ('show all pictures around this location')+'>'+
            imgShowAll+ '<span>'+Localization.get('Show all')+'</span>'+
          '</a>';
  content += '</div>';
  content += '<div id="pwgImageDetail">' + this.buildCurrentPictureHtml( marker ) + '</div>';

  marker.openInfoWindowHtml( content );

  // bind to next / prev a little later because sometimes the nodes are not immediately created
  if (this._timerBindPictureNavigation) clearTimeout(this._timerBindPictureNavigation);
  this._timerBindPictureNavigation = null;
  if (marker.images.length>1)
    this._timerBindPictureNavigation = setTimeout( this._onTimeoutBindPictureNavigation.bind(this, marker), 500 );
},

buildCurrentPictureHtml: function( marker )
{
  var imageDetail = marker.images[marker.currentImageIndex];
  var res = "";
  res += '<div class="gmiw_imageTitle">' + imageDetail.name + "</div>";
  res +=
'<div class="gmiw_imageContent">' +
'<div class="gmiw_imageWrap">'+
  '<a href="'+imageDetail.page_url+'">' +
  '<img src="' + imageDetail.tn + '" alt="thumb" />'+
'</a></div>' +
'<div class="gmiw_imageComment">' + imageDetail.comment + '</div>' +
'</div>';
  return res;
},

buildCurrentPictureCounterHtml: function( marker )
{
  var res =
    '<b>'+(marker.currentImageIndex+1)+'</b>'+
    '/' +
    '<b>'+marker.images.length+'</b>';
  return res;
},


_onTimeoutBindPictureNavigation: function( marker )
{
  clearTimeout(this._timerBindPictureNavigation);
  this._timerBindPictureNavigation = null;
  for (var i=0; i< this._navHtmlIds.length; i++)
  {
    var elt = document.getElementById( this._navHtmlIds[i] );
    if (elt)
      GEvent.addDomListener(elt, "click", this._onPictureNavigate.bind(this, marker, i) );
  }
},

_onPictureNavigate: function(marker, dir )
{
  if (dir==0) dir=-1;
  marker.currentImageIndex += dir;
  if (marker.currentImageIndex<0)
    marker.currentImageIndex = marker.images.length-1;
  else if (marker.currentImageIndex >= marker.images.length)
    marker.currentImageIndex = 0;

  try {
    var elt = document.getElementById( "pwgImageDetail" );
    elt.innerHTML = this.buildCurrentPictureHtml( marker );
  }
  catch (e)
  {
    alert (e.message);
  }

  try {
    var elt = document.getElementById( "pwgImageCounters" );
    elt.innerHTML = this.buildCurrentPictureCounterHtml( marker );
  }
  catch (e)
  {
    alert (e.message);
  }
  return false;
}

}

PwgDataHandler.blowupUrl = function(theUrl)
{
  var win = new Window({
    title: document.title,
    url: theUrl,
    classname: "alphacube",
    left: 0, top: 0,
    width:"640", height:"480",
    minimizable: false,
    maximizable: false,
    draggable: false,
    resizable: false,
    destroyOnClose: true,
    hideEffect: Element.hide,
    showEffectOptions: {duration:1.5}
  });

  win.setConstraint(true, {top:20, left:20, bottom:30, right:20} );
  win.maximize();
  win.showCenter(true, 20, 20);
  return false;
}


String.prototype.urlNoHtm = function()
{
  return this.replace( "&amp;", "&" );
}
